@@ -13,6 +13,7 @@ class BallotMeasuresCdAdmin(BaseAdmin):
     """
     Custom admin for the BallotMeasuresCd model.
     """
+
     list_display = ("measure_name", "election_date", "jurisdiction")
 
 
@@ -21,7 +22,11 @@ class CvrF470CdAdmin(BaseAdmin):
     """
     Custom admin for the CvrF470Cd model.
     """
-    list_display = ("filing_id", "filer_naml",)
+
+    list_display = (
+        "filing_id",
+        "filer_naml",
+    )
 
 
 @admin.register(models.FilerTypePeriodsCd)
@@ -29,6 +34,7 @@ class FilerTypePeriodsCd(BaseAdmin):
     """
     Custom admin for the FilerTypePeriodsCd model.
     """
+
     list_display = ("election_type", "filer_type", "period_id")
 
 
@@ -37,12 +43,8 @@ class LobbyistContributions1CdAdmin(BaseAdmin):
     """
     Custom admin for the LobbyistContributions1Cd model.
     """
-    list_display = (
-        "filer_id",
-        "filing_period_start_dt",
-        "recipient_name",
-        "amount"
-    )
+
+    list_display = ("filer_id", "filing_period_start_dt", "recipient_name", "amount")
     date_hierarchy = "filing_period_start_dt"
 
 
@@ -51,12 +53,8 @@ class LobbyistContributions2CdAdmin(BaseAdmin):
     """
     Custom admin for the LobbyistContributions2Cd model.
     """
-    list_display = (
-        "filer_id",
-        "filing_period_start_dt",
-        "recipient_name",
-        "amount"
-    )
+
+    list_display = ("filer_id", "filing_period_start_dt", "recipient_name", "amount")
     date_hierarchy = "filing_period_start_dt"
 
 
@@ -65,12 +63,8 @@ class LobbyistContributions3CdAdmin(BaseAdmin):
     """
     Custom admin for the LobbyistContributions3Cd model.
     """
-    list_display = (
-        "filer_id",
-        "filing_period_start_dt",
-        "recipient_name",
-        "amount"
-    )
+
+    list_display = ("filer_id", "filing_period_start_dt", "recipient_name", "amount")
     date_hierarchy = "filing_period_start_dt"
 
 
@@ -79,6 +73,7 @@ class LobbyistEmpLobbyist1CdAdmin(BaseAdmin):
     """
     Custom admin for the LobbyistEmpLobbyist1Cd model.
     """
+
     list_display = (
         "lobbyist_id",
         "employer_id",
@@ -94,6 +89,7 @@ class LobbyistEmpLobbyist2CdAdmin(BaseAdmin):
     """
     Custom admin for the LobbyistEmpLobbyist2Cd model.
     """
+
     list_display = (
         "lobbyist_id",
         "employer_id",
@@ -109,6 +105,7 @@ class LobbyistEmployer1CdAdmin(BaseAdmin):
     """
     Custom admin for the LobbyistEmployer1Cd model.
     """
+
     list_display = (
         "employer_id",
         "session_id",
@@ -122,6 +119,7 @@ class LobbyistEmployer2CdAdmin(BaseAdmin):
     """
     Custom admin for the LobbyistEmployer2Cd model.
     """
+
     list_display = (
         "employer_id",
         "session_id",
@@ -135,6 +133,7 @@ class LobbyistEmployer3CdAdmin(BaseAdmin):
     """
     Custom admin for the LobbyistEmployer3Cd model.
     """
+
     list_display = (
         "employer_id",
         "session_id",
@@ -148,6 +147,7 @@ class LobbyistEmployerFirms1CdAdmin(BaseAdmin):
     """
     Custom admin for the LobbyistEmployerFirms1Cd model.
     """
+
     list_display = (
         "firm_id",
         "employer_id",
@@ -162,6 +162,7 @@ class LobbyistEmployerFirms2CdAdmin(BaseAdmin):
     """
     Custom admin for the LobbyistEmployerFirms2Cd model.
     """
+
     list_display = (
         "firm_id",
         "employer_id",
@@ -176,6 +177,7 @@ class LobbyistEmployerHistoryCdAdmin(BaseAdmin):
     """
     Custom admin for the LobbyistEmployerHistoryCd model.
     """
+
     list_display = ("employer_id", "employer_name")
 
 
@@ -184,6 +186,7 @@ class LobbyistFirm1CdAdmin(BaseAdmin):
     """
     Custom admin for the LobbyistFirm1Cd model.
     """
+
     list_display = (
         "firm_id",
         "firm_name",
@@ -198,6 +201,7 @@ class LobbyistFirm2CdAdmin(BaseAdmin):
     """
     Custom admin for the LobbyistFirm2Cd model.
     """
+
     list_display = (
         "firm_id",
         "firm_name",
@@ -212,6 +216,7 @@ class LobbyistFirm3CdAdmin(BaseAdmin):
     """
     Custom admin for the LobbyistFirm3Cd model.
     """
+
     list_display = (
         "firm_id",
         "firm_name",
@@ -226,6 +231,7 @@ class LobbyistFirmEmployer1CdAdmin(BaseAdmin):
     """
     Custom admin for the LobbyistFirm2Cd model.
     """
+
     list_display = (
         "filing_id",
         "firm_name",
@@ -240,6 +246,7 @@ class LobbyistFirmEmployer2CdAdmin(BaseAdmin):
     """
     Custom admin for the LobbyistFirmEmployer2Cd model.
     """
+
     list_display = (
         "filing_id",
         "firm_name",
@@ -254,6 +261,7 @@ class LobbyistFirmHistoryCdAdmin(BaseAdmin):
     """
     Custom admin for the LobbyistFirm2Cd model.
     """
+
     list_display = ("contributor_id", "firm_id", "session_id")
 
 
@@ -262,13 +270,14 @@ class LobbyistFirmLobbyist1CdAdmin(BaseAdmin):
     """
     Custom admin for the LobbyistFirm2Cd model.
     """
+
     list_display = (
         "lobbyist_id",
         "firm_id",
         "session_id",
         "lobbyist_first_name",
         "lobbyist_last_name",
-        "firm_name"
+        "firm_name",
     )
 
 
@@ -277,13 +286,14 @@ class LobbyistFirmLobbyist2CdAdmin(BaseAdmin):
     """
     Custom admin for the LobbyistFirm2Cd model.
     """
+
     list_display = (
         "lobbyist_id",
         "firm_id",
         "session_id",
         "lobbyist_first_name",
         "lobbyist_last_name",
-        "firm_name"
+        "firm_name",
     )
 
 
@@ -292,6 +302,7 @@ class EfsFilingLogCdAdmin(BaseAdmin):
     """
     Custom admin for the EfsFilingLogCd model.
     """
+
     list_display = (
         "id",
         "vendor",
