@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """
 Configuration of the Django app.
 """
@@ -10,6 +8,7 @@ class CalAccessRawConfig(AppConfig):
     """
     Configuration of the `calaccess_raw` Django app.
     """
-    name = 'calaccess_raw'
+
+    name = "calaccess_raw"
     verbose_name = "CAL-ACCESS raw data"
-    default_auto_field = 'django.db.models.BigAutoField'
+    default_auto_field = "django.db.models.BigAutoField"
