@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """
 Tests annotations of the data.
 """
@@ -12,6 +10,7 @@ from calaccess_raw import annotations
 
 # Logging
 import logging
+
 logger = logging.getLogger(__name__)
 
 
@@ -19,13 +18,14 @@ class AnnotationTestCase(TestCase):
     """
     Tests annotations of the data.
     """
+
     multi_db = True
 
     def test_filingform(self):
         """
         Test attributes of the FilingForm object.
         """
-        ff = annotations.get_form('F400')
+        ff = annotations.get_form("F400")
         ff.get_models()
         ff.__str__()
         s = ff.get_section("P1")
@@ -35,7 +35,7 @@ class AnnotationTestCase(TestCase):
         """
         Test attributes of the DocumentCloud object.
         """
-        dc = annotations.DocumentCloud('2753585', 1, 1)
+        dc = annotations.DocumentCloud("2753585", 1, 1)
         if os.path.exists(dc.metadata_filename):
             os.remove(dc.metadata_filename)
         dc.metadata
@@ -48,13 +48,13 @@ class AnnotationTestCase(TestCase):
         dc.num_pages
         dc.pages
         dc.formatted_page_nums
-        dc2 = annotations.DocumentCloud('2753585')
+        dc2 = annotations.DocumentCloud("2753585")
         dc2.canonical_url
         dc2.num_pages
         dc2.formatted_page_nums
-        dc3 = annotations.DocumentCloud('2753585', None, 1)
+        dc3 = annotations.DocumentCloud("2753585", None, 1)
         dc3.num_pages
         dc3.formatted_page_nums
-        dc4 = annotations.DocumentCloud('2753585', 1, None)
+        dc4 = annotations.DocumentCloud("2753585", 1, None)
         dc4.num_pages
         dc4.formatted_page_nums
